﻿using Infragistics.Win;
using Infragistics.Win.UltraWinForm;
using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace UltraFormHeader
{
    public class MyDrawFilter : IUIElementDrawFilter
    {
        private string leftText;
        private string rightText;
        private Font currentFont;

        public MyDrawFilter(string leftText, string rightText, Font currentFont)
        {
            this.leftText = leftText;
            this.rightText = rightText;
            this.currentFont = currentFont;
        }

        public bool DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
            UltraFormCaptionUIElement caption = drawParams.Element as UltraFormCaptionUIElement;
            if (null == caption)
            {
                return false;
            }

            Rectangle captionRect = caption.Rect;
            Size leftTextSize = TextRenderer.MeasureText(this.leftText, this.currentFont);

            Size rightTextSize = TextRenderer.MeasureText(this.rightText, this.currentFont);
            if (leftTextSize.Width + rightTextSize.Width + 5 > captionRect.Width)
            {
                return false;
            }

            Point rightTextStartPoint = new Point(captionRect.Right - rightTextSize.Width, captionRect.Y + 4);
            drawParams.Graphics.DrawString(this.rightText, this.currentFont, Brushes.DimGray, rightTextStartPoint);

            return false;
        }

        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            UltraFormCaptionUIElement caption = drawParams.Element as UltraFormCaptionUIElement;
            if (caption != null)
            {
                return DrawPhase.BeforeDrawChildElements;
            }

            return DrawPhase.None;
        }
    }
}